pub enum AppMouseAction {
Move {
x: f64,
y: f64,
},
Down {
x: f64,
y: f64,
button: AppMouseButton,
},
Up {
x: f64,
y: f64,
button: AppMouseButton,
},
Click {
x: f64,
y: f64,
button: AppMouseButton,
click_count: u8,
},
Drag {
from_x: f64,
from_y: f64,
to_x: f64,
to_y: f64,
button: AppMouseButton,
},
Scroll {
x: f64,
y: f64,
dx: f64,
dy: f64,
},
}Expand description
App-window mouse action.
Coordinates are logical points in the target window content area, with
origin at the top-left corner of the same visual content captured by
AppScreenshot::take_app_screenshot.
Variants
Implementations